var domain = 'sipjs.onsip.com';
var aliceURI      = 'alice' + '@' + domain;
var aliceName     = 'Alice';

var bobURI        = 'bob' + '@' + domain;
var bobName       = 'Bob';

// A shortcut function to construct the media options for an SIP session.
function mediaOptions(audio, video, remoteRender, localRender) {
    return {
        media: {
            constraints: {
                audio: audio,
                video: video
            },
            render: {
                remote: {
                    video: remoteRender
                },
                local: {
                    video: localRender
                }
            }
        }
    };
}

// Makes a call from a user agent to a target URI
function makeCall(userAgent, target, audio, video, remoteRender, localRender) {
    var options = mediaOptions(audio, video, remoteRender, localRender);
    // makes the call
    var session = userAgent.invite('sip:' + target, options);
    return session;
}

function setUpVideoInterface(userAgent, target, remoteRenderId) {
    var onCall = false;
    var session;
    var remoteRender = document.getElementById(remoteRenderId);

    // Handling invitations to calls.
    // Also, for each new call session, we need to add an event handler to set
    // the correct state when we receive a "bye" request.
    userAgent.on('invite', function (incomingSession) {
        onCall = true;
        session = incomingSession;
        var options = mediaOptions(false, true, remoteRender, null);
        remoteRender.style.visibility = 'visible';
        session.accept(options);
        session.on('bye', function () {
            onCall = false;
            remoteRender.style.visibility = 'hidden';
            session = null;
        });
    });
            onCall = true;
    remoteRender.style.visibility = 'visible';
    session = makeCall(userAgent, target,
                       false, true,
                       remoteRender, null);
    session.on('bye', function () {
        onCall = false;
        remoteRender.style.visibility = 'hidden';
        session = null;
    });
}


var aliceUA = new SIP.UA({
        traceSip: true,
        uri: aliceURI,
        displayName: aliceName
    });
setUpVideoInterface(aliceUA, bobURI, 'video-of-bob');
